@@ -19,14 +19,20 @@ class PfdConfig(NestingModel):
     """configuration for `pfd`"""
     ias_never_exceed: float = 167.0
     """Never exceed speed (Vne) shown on IAS tape"""
-    rotate_adi_target: bool = True
+    show_adi_target: bool = True
+    """Display the attitude target after receiving trgt.att"""
+    adi_target_roll: bool = True
     """Rotate attitude target indicator to show desired roll"""
+    adi_target_yaw: bool = False
+    """Move attitude target indicator to show desired yaw"""
     show_flightpath: bool = True
     """Show flightpath vector (FPV) indicator on ADI"""
     show_retrograde: bool = False
     """Show reverse flight path vector on ADI"""
     move_roll_ticks: bool = False
     """Move roll angle scale with horizon, keeping sideslip triangle in place"""
+    sideslip_max: float = 15.0
+    """Maximal displayed sideslip angle, in degrees"""
 
 
 class ApproachConfig(NestingModel):
@@ -81,7 +87,7 @@ class Config(NestingModel):
     Every config field in this and children should be provided with defaults,
     that can be overriden by config files"""
 
-    dollar_schema: Optional[str] = Field(alias='$schema', default=None)
+    json_schema_url: Optional[str] = Field(alias='$schema', default=None)
     """Allow the `$schema` property for specifying JSON Schema URL"""
     rpctask = RpctaskConfig()
     pfd = PfdConfig()
